@@ -8,7 +8,6 @@ from io import BytesIO
 import os
 from stat import S_ISLNK
 import subprocess
-import sys
 import tempfile
 
 from git.compat import (
@@ -18,7 +17,6 @@ from git.compat import (
     force_bytes,
     defenc,
     mviter,
-    is_win
 )
 from git.exc import (
     GitCommandError,
@@ -121,20 +119,14 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
                 ok = True
             except OSError:
                 # in new repositories, there may be no index, which means we are empty
-                self.entries = dict()
+                self.entries = {}
                 return
             finally:
                 if not ok:
                     lfd.rollback()
             # END exception handling
 
-            # Here it comes: on windows in python 2.5, memory maps aren't closed properly
-            # Hence we are in trouble if we try to delete a file that is memory mapped,
-            # which happens during read-tree.
-            # In this case, we will just read the memory in directly.
-            # Its insanely bad ... I am disappointed !
-            allow_mmap = (is_win or sys.version_info[1] > 5)
-            stream = file_contents_ro(fd, stream=True, allow_mmap=allow_mmap)
+            stream = file_contents_ro(fd, stream=True, allow_mmap=True)
 
             try:
                 self._deserialize(stream)
@@ -166,7 +158,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
 
     def _deserialize(self, stream):
         """Initialize this instance with index values read from the given stream"""
-        self.version, self.entries, self._extension_data, conten_sha = read_cache(stream)  # @UnusedVariable
+        self.version, self.entries, self._extension_data, _conten_sha = read_cache(stream)
         return self
 
     def _entries_sorted(self):
@@ -324,7 +316,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         if len(treeish) == 0 or len(treeish) > 3:
             raise ValueError("Please specify between 1 and 3 treeish, got %i" % len(treeish))
 
-        arg_list = list()
+        arg_list = []
         # ignore that working tree and index possibly are out of date
         if len(treeish) > 1:
             # drop unmerged entries when reading our index and merging
@@ -400,7 +392,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
                     continue
             # END glob handling
             try:
-                for root, dirs, files in os.walk(abs_path, onerror=raise_exc):  # @UnusedVariable
+                for root, _dirs, files in os.walk(abs_path, onerror=raise_exc):
                     for rela_file in files:
                         # add relative paths only
                         yield osp.join(root.replace(rs, ''), rela_file)
@@ -471,9 +463,9 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
             are at stage 3 will not have a stage 3 entry.
         """
         is_unmerged_blob = lambda t: t[0] != 0
-        path_map = dict()
+        path_map = {}
         for stage, blob in self.iter_blobs(is_unmerged_blob):
-            path_map.setdefault(blob.path, list()).append((stage, blob))
+            path_map.setdefault(blob.path, []).append((stage, blob))
         # END for each unmerged blob
         for l in mviter(path_map):
             l.sort()
@@ -569,15 +561,17 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
             return path
         if self.repo.bare:
             raise InvalidGitRepositoryError("require non-bare repository")
-        relative_path = path.replace(self.repo.working_tree_dir + os.sep, "")
-        if relative_path == path:
+        if not path.startswith(self.repo.working_tree_dir):
             raise ValueError("Absolute path %r is not in git repository at %r" % (path, self.repo.working_tree_dir))
-        return relative_path
+        return os.path.relpath(path, self.repo.working_tree_dir)
 
     def _preprocess_add_items(self, items):
         """ Split the items into two lists of path strings and BaseEntries. """
-        paths = list()
-        entries = list()
+        paths = []
+        entries = []
+        # if it is a string put in list
+        if isinstance(items, str):
+            items = [items]
 
         for item in items:
             if isinstance(item, string_types):
@@ -589,7 +583,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
             else:
                 raise TypeError("Invalid Type: %r" % item)
         # END for each item
-        return (paths, entries)
+        return paths, entries
 
     def _store_path(self, filepath, fprogress):
         """Store file at filepath in the database and return the base index entry
@@ -610,7 +604,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
     @unbare_repo
     @git_working_dir
     def _entries_for_paths(self, paths, path_rewriter, fprogress, entries):
-        entries_added = list()
+        entries_added = []
         if path_rewriter:
             for path in paths:
                 if osp.isabs(path):
@@ -742,7 +736,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         # automatically
         # paths can be git-added, for everything else we use git-update-index
         paths, entries = self._preprocess_add_items(items)
-        entries_added = list()
+        entries_added = []
         # This code needs a working tree, therefore we try not to run it unless required.
         # That way, we are OK on a bare repository as well.
         # If there are no paths, the rewriter has nothing to do either
@@ -809,7 +803,11 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
     def _items_to_rela_paths(self, items):
         """Returns a list of repo-relative paths from the given items which
         may be absolute or relative paths, entries or blobs"""
-        paths = list()
+        paths = []
+        # if string put in list
+        if isinstance(items, str):
+            items = [items]
+
         for item in items:
             if isinstance(item, (BaseIndexEntry, (Blob, Submodule))):
                 paths.append(self._to_relative_path(item.path))
@@ -858,7 +856,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
             been removed effectively.
             This is interesting to know in case you have provided a directory or
             globs. Paths are relative to the repository. """
-        args = list()
+        args = []
         if not working_tree:
             args.append("--cached")
         args.append("--")
@@ -897,7 +895,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
 
         :raise ValueError: If only one item was given
             GitCommandError: If git could not handle your request"""
-        args = list()
+        args = []
         if skip_errors:
             args.append('-k')
 
@@ -910,7 +908,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
 
         # first execute rename in dryrun so the command tells us what it actually does
         # ( for later output )
-        out = list()
+        out = []
         mvlines = self.repo.git.mv(args, paths, **kwargs).splitlines()
 
         # parse result - first 0:n/2 lines are 'checking ', the remaining ones
@@ -948,6 +946,11 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         :return: Commit object representing the new commit"""
         if not skip_hooks:
             run_commit_hook('pre-commit', self)
+
+            self._write_commit_editmsg(message)
+            run_commit_hook('commit-msg', self, self._commit_editmsg_filepath())
+            message = self._read_commit_editmsg()
+            self._remove_commit_editmsg()
         tree = self.write_tree()
         rval = Commit.create_from_tree(self.repo, tree, message, parent_commits,
                                        head, author=author, committer=committer,
@@ -955,6 +958,20 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         if not skip_hooks:
             run_commit_hook('post-commit', self)
         return rval
+    
+    def _write_commit_editmsg(self, message):
+        with open(self._commit_editmsg_filepath(), "wb") as commit_editmsg_file:
+            commit_editmsg_file.write(message.encode(defenc))
+
+    def _remove_commit_editmsg(self):
+        os.remove(self._commit_editmsg_filepath())
+
+    def _read_commit_editmsg(self):
+        with open(self._commit_editmsg_filepath(), "rb") as commit_editmsg_file:
+            return commit_editmsg_file.read().decode(defenc)
+
+    def _commit_editmsg_filepath(self):
+        return osp.join(self.repo.common_dir, "COMMIT_EDITMSG")
 
     @classmethod
     def _flush_stdin_and_wait(cls, proc, ignore_stdout=False):
@@ -1022,9 +1039,9 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
             # line contents:
             stderr = stderr.decode(defenc)
             # git-checkout-index: this already exists
-            failed_files = list()
-            failed_reasons = list()
-            unknown_lines = list()
+            failed_files = []
+            failed_reasons = []
+            unknown_lines = []
             endings = (' already exists', ' is not in the cache', ' does not exist at stage', ' is unmerged')
             for line in stderr.splitlines():
                 if not line.startswith("git checkout-index: ") and not line.startswith("git-checkout-index: "):
@@ -1087,7 +1104,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
             proc = self.repo.git.checkout_index(args, **kwargs)
             # FIXME: Reading from GIL!
             make_exc = lambda: GitCommandError(("git-checkout-index",) + tuple(args), 128, proc.stderr.read())
-            checked_out_files = list()
+            checked_out_files = []
 
             for path in paths:
                 co_path = to_native_path_linux(self._to_relative_path(path))
