@@ -2,15 +2,13 @@
 # This module is part of GitPython and is released under
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
 import os
+import shutil
 import sys
-try:
-    from unittest import skipIf
-except ImportError:
-    from unittest2 import skipIf
+from unittest import skipIf
 
 import git
 from git.cmd import Git
-from git.compat import string_types
+from git.compat import string_types, is_win
 from git.exc import (
     InvalidGitRepositoryError,
     RepositoryDirtyError
@@ -267,7 +265,7 @@ class TestSubmodule(TestBase):
             self.failUnlessRaises(ValueError, csm.remove, module=False, configuration=False)
 
             # module() is supposed to point to gitdb, which has a child-submodule whose URL is still pointing
-            # to github. To save time, we will change it to
+            # to GitHub. To save time, we will change it to
             csm.set_parent_commit(csm.repo.head.commit)
             with csm.config_writer() as cw:
                 cw.set_value('url', self._small_repo_url())
@@ -482,9 +480,8 @@ class TestSubmodule(TestBase):
         with sm.config_writer() as writer:
             writer.set_value('path', fp)    # change path to something with prefix AFTER url change
 
-        # update fails as list_items in such a situations cannot work, as it cannot
-        # find the entry at the changed path
-        self.failUnlessRaises(InvalidGitRepositoryError, rm.update, recursive=False)
+        # update doesn't fail, because list_items ignores the wrong path in such situations.
+        rm.update(recursive=False)
 
         # move it properly - doesn't work as it its path currently points to an indexentry
         # which doesn't exist ( move it to some path, it doesn't matter here )
@@ -663,12 +660,31 @@ class TestSubmodule(TestBase):
                                   url=empty_repo_dir, no_checkout=checkout_mode and True or False)
         # end for each checkout mode
 
-    @skipIf(HIDE_WINDOWS_KNOWN_ERRORS and Git.is_cygwin(),
-            """FIXME: ile "C:\\projects\\gitpython\\git\\cmd.py", line 671, in execute
+    @with_rw_directory
+    def test_list_only_valid_submodules(self, rwdir):
+        repo_path = osp.join(rwdir, 'parent')
+        repo = git.Repo.init(repo_path)
+        repo.git.submodule('add', self._small_repo_url(), 'module')
+        repo.index.commit("add submodule")
+
+        assert len(repo.submodules) == 1
+
+        # Delete the directory from submodule
+        submodule_path = osp.join(repo_path, 'module')
+        shutil.rmtree(submodule_path)
+        repo.git.add([submodule_path])
+        repo.index.commit("remove submodule")
+
+        repo = git.Repo(repo_path)
+        assert len(repo.submodules) == 0
+
+    @skipIf(HIDE_WINDOWS_KNOWN_ERRORS,
+            """FIXME on cygwin: File "C:\\projects\\gitpython\\git\\cmd.py", line 671, in execute
                 raise GitCommandError(command, status, stderr_value, stdout_value)
             GitCommandError: Cmd('git') failed due to: exit code(128)
               cmdline: git add 1__Xava verbXXten 1_test _myfile 1_test_other_file 1_XXava-----verbXXten
               stderr: 'fatal: pathspec '"1__çava verböten"' did not match any files'
+             FIXME on appveyor: see https://ci.appveyor.com/project/Byron/gitpython/build/1.0.185
                 """)
     @with_rw_directory
     def test_git_submodules_and_add_sm_with_new_commit(self, rwdir):
@@ -698,6 +714,9 @@ class TestSubmodule(TestBase):
 
         parent.index.commit("moved submodules")
 
+        with sm.config_writer() as writer:
+            writer.set_value('user.email', 'example@example.com')
+            writer.set_value('user.name', 'me')
         smm = sm.module()
         fp = osp.join(smm.working_tree_dir, 'empty-file')
         with open(fp, 'w'):
@@ -907,3 +926,13 @@ class TestSubmodule(TestBase):
         parent_repo.submodule_update(to_latest_revision=True, force_reset=True)
         assert sm_mod.commit() == sm_pfb.commit, "Now head should have been reset"
         assert sm_mod.head.ref.name == sm_pfb.name
+
+    @skipIf(not is_win, "Specifically for Windows.")
+    def test_to_relative_path_with_super_at_root_drive(self):
+        class Repo(object):
+            working_tree_dir = 'D:\\'
+        super_repo = Repo()
+        submodule_path = 'D:\\submodule_path'
+        relative_path = Submodule._to_relative_path(super_repo, submodule_path)
+        msg = '_to_relative_path should be "submodule_path" but was "%s"' % relative_path
+        assert relative_path == 'submodule_path', msg
